@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import contextlib
-from typing import TYPE_CHECKING, ClassVar, Mapping
+from typing import TYPE_CHECKING, ClassVar
 from weakref import WeakValueDictionary
 
 from app_model import Application
@@ -12,6 +12,8 @@ from ._qkeymap import QKeyBindingSequence
 from ._util import to_qicon
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from PyQt6.QtGui import QAction
     from qtpy.QtCore import QObject
     from typing_extensions import Self
@@ -44,8 +46,10 @@ class QCommandAction(QAction):
         self._app = Application.get_or_create(app) if isinstance(app, str) else app
         self._command_id = command_id
         self.setObjectName(command_id)
+        self._keybinding_tooltip = ""
         if kb := self._app.keybindings.get_keybinding(command_id):
             self.setShortcut(QKeyBindingSequence(kb.keybinding))
+            self._keybinding_tooltip = f"({kb.keybinding.to_text()})"
         self.triggered.connect(self._on_triggered)
 
     def _on_triggered(self, checked: bool) -> None:
@@ -94,6 +98,10 @@ class QCommandRuleAction(QCommandAction):
         if command_rule.toggled is not None:
             self.setCheckable(True)
             self._refresh()
+        tooltip_with_keybinding = (
+            f"{self.toolTip()} {self._keybinding_tooltip}".rstrip()
+        )
+        self.setToolTip(tooltip_with_keybinding)
 
     def update_from_context(self, ctx: Mapping[str, object]) -> None:
         """Update the enabled state of this menu item from `ctx`."""
