@@ -3,7 +3,7 @@ from __future__ import annotations
 
 import operator
 from functools import reduce
-from typing import TYPE_CHECKING, Mapping, MutableMapping
+from typing import TYPE_CHECKING
 
 from qtpy import API, QT_VERSION
 from qtpy.QtCore import QCoreApplication, Qt
@@ -19,6 +19,8 @@ from app_model.types import (
 from app_model.types._constants import OperatingSystem
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping, MutableMapping
+
     from qtpy.QtCore import QKeyCombination
 
 try:
@@ -64,7 +66,9 @@ if QT6:
         )
         key = modelkey2qkey(skb.key) if skb.key else Qt.Key.Key_unknown
         mods = (v for k, v in lookup.items() if getattr(skb, k))
-        combo = QKeyCombination(reduce(operator.or_, mods), key)
+        combo = QKeyCombination(
+            reduce(operator.or_, mods, Qt.KeyboardModifier.NoModifier), key
+        )
         return int(combo.toCombined())
 
 else:
